#author = "Kang Yang"
#copyright = "Copyright 2017, UCLA Greenland Hydrology Group"
#license = "GPL"
#version = "0.1"
#maintainer = "Kang Yang"
#email = "kangyang@ucla.edu"
#status = "Production"
#description = "create basin cells for smb models"

import arcpy,os,sys
from arcpy import env
from arcpy.da import SearchCursor #source: http://gis.stackexchange.com/questions/120335/why-does-arcpy-da-searchcursor-class-not-autocomplete-within-eclipse/175324#175324
import numpy
import csv

def findField(fc, fi):
  lst = arcpy.ListFields(fc)
  for f in lst:
    if f.name == fi:    
      return "found"
  return "not found"

def dbf2csv(dbfpath, csvpath, keep,basinID):
    csvFile = csv.writer(open(csvpath, 'wb')) 
    result = arcpy.GetCount_management(dbfpath)
    count = int(result.getOutput(0))
    if count == 1:  #it is wired that arcpy.SearchCursor does not work when there is only one feautre
        rows = SearchCursor(dbfpath,keep)
        csvFile = csv.writer(open(csvpath, 'wb')) 
        #csvFile.writerow(keep) #uncomment this line if you want to keep field names as the first row
        for row in rows:
            csvFile.writerow(row)
    else:
        #csvFile.writerow(keep) #uncomment this line if you want to keep field names as the first row
        rows = arcpy.SearchCursor(dbfpath,sort_fields=basinID + " A") #2017.01.26, add sort_fields to sort csv table
        allRows = []
        for row in rows:
            rowlist = []
            for field in keep:
                rowlist.append(row.getValue(field))
            allRows.append(rowlist)
        for row in allRows:
            csvFile.writerow(row)

def create_IDC_parts_for_SMB_calculation (cellFile, basins, cellAreaField, idField, outputpath,outputCSVBasin):
  env.extent = arcpy.Describe(basins).extent
  #intersect
  outputBasin = outputCSVBasin.split('.')[0]+".shp"
  arcpy.Intersect_analysis([cellFile,basins],outputBasin)
  print "intersect done"
  #add area field
  if findField(outputBasin,"area")=="found":
    arcpy.DeleteField_management(outputBasin, "area")
  arcpy.AddField_management(outputBasin, "area", "DOUBLE")
  arcpy.CalculateField_management(outputBasin, "area", "!SHAPE.AREA@SQUAREKILOMETERS!", "PYTHON_9.3")
  arcpy.AddField_management(outputBasin, "percentage", "DOUBLE")
  arcpy.CalculateField_management(outputBasin, "percentage", "!area!/!" + cellAreaField + "!", "PYTHON_9.3")
  # the attributes to keep, note cell area is kept here, unlike MAR because the other SMB model cells have different areas
  #2017.02.01, a key update here. for 5 km reprojected cells, lonN and latN are used to identify cell location number; for other original cells (e.g., 20 km MAR cells), lon and lat are used to store actual lat and lon
  #values. This leads to different processing approches in the Step 2 Matlab codes as well.
  #if "_5km" in cellFile:
  #    keep = [idField,'lonN', 'latN', 'percentage',cellAreaField]
  #else:
  keep = [idField,'lon', 'lat', 'percentage',cellAreaField]
  discard = []
  fields=arcpy.ListFields(outputBasin)
  for field in fields:
    if field.type=='Geometry' or field.name=='FID':
      continue
    if field.name not in keep:
      discard.append(field.name)
  arcpy.DeleteField_management(outputBasin, discard)     
  print "field processing done" 
  #generate csv file
  dbf2csv(outputBasin, outputpath + "\\" + outputCSVBasin, keep,idField)
  print "generate CSV file done"
  #arcpy.Delete_management(outputBasin)  #comment this line if you want to keep the output basin Shapefile
  
    
#input
outputpath=r'E:\1.GrIS_river_evolution\1_SMB_outputs' # INPUT 1: the output folder
if os.path.exists(outputpath)==False:
        os.mkdir(outputpath)
env.overwriteOutput=True
env.workspace = outputpath

####-----------------------PART1, SMB Cell Input (25 km, 20 km, 7.5 km, 5 km) ---------------------------####

cellFile=r'D:\MAR_RACMO_Proglacial_Lincoln\MAR_7_5km\mar_7_5km_lat_lon_ps_cells.shp' #INPUT 2: input reproject MAR grid cell (polygon) files
# Find a bug on 4/28/2016, projection of the original cell file is MAR customized projection, which is different from the PS projection (the one I used to calculate WQ7 areas. Cell areas calculated from two
# projections are different. This will lead to slight bias. To fix this problem, I projected cell file to PS projection and calculated areas consistently.
cellAreaField="smbArea" # INPUT 3: name of the cell area field


basins = r'E:\1.GrIS_river_evolution\1_DEM\basin_watson_isortoq_30m_gimp_v2_reclassfication_polygon.shp'
idField="Id" # INPUT 4: name of the basin name field, need to be Int type, IMPORTANT!
outputCSVBasin_IDCs_bestguess="mar_7_5km_ps_cells_for_basin_Watson_Isortoq_matlab.csv"   
#runff the main function
create_IDC_parts_for_SMB_calculation (cellFile, basins, cellAreaField, idField, outputpath,outputCSVBasin_IDCs_bestguess)



####--------------------------------------------END-----------------------------------------------####

