# use Miniconda environment
#author = "Kang Yang"
#copyright = "Copyright 2017, Nanjing Greenland Hydrology Group"
#license = "GPL"
#version = "0.1"
#maintainer = "Kang Yang"
#email = "kangyang@nju.edu.cn"
#status = "Production"
#description = "calculate runoffs for all SMB models"
import os
import pandas as pd
import numpy as np
import matplotlib.pyplot as plt
import matplotlib
import pysal as ps
from matplotlib import cm


def get_eleBin_area(input_zonalSta_waterarea_point_file):
    dbf = ps.open(input_zonalSta_waterarea_point_file)
    d = dbf.by_col_array(dbf.header)
    df = pd.DataFrame(d)
    df.columns = dbf.header
    df = df.T
    df.columns = ['<1000 m','1000-1200 m', '1200-1400 m','1400-1600 m','1600-1800 m','>1800 m']

    areaIdx = 'area'
    area = df.loc[areaIdx]

    return area

def get_axis_limits(ax, scale1=0.0,scale2=0.95):
    return ax.get_xlim()[1]*scale1, ax.get_ylim()[1]*scale2

def create_SMB_DF(input_SMBExcelFile):
    filename, ext = os.path.splitext(input_SMBExcelFile)
    if ext == '.xlsx':
        data = pd.read_excel(input_SMBExcelFile)
    if ext == '.csv':
        data = pd.read_csv(input_SMBExcelFile)
    df = pd.DataFrame(data)
    df = df.T
    df.columns = ['<1000 m','1000-1200 m', '1200-1400 m','1400-1600 m','1600-1800 m','>1800 m']
    if ext == '.xlsx':
        days = df.index[:]
    if ext == '.csv':
        days = df.index[1:-1]  #In csv files, the first index is 'basin', which needs to be deleted
        df = df.iloc[1:-1]
        
    df.index = [int(day[3:]) for day in days]
    print df
    return df

def select_doy_Runoff_from_all(df_runoff,acc_df_all_runoff):
    days = df_runoff.index[:]
    acc_doy_runoff = acc_df_all_runoff.loc[days]
    return acc_doy_runoff


def create_all_SMB_DF(input_smb_file,area):
    data = pd.read_excel(input_smb_file)
    df = pd.DataFrame(data)
    df['DOY'] = df.index
    cols = list(df)
    mar_cols = [c for c in cols if 'mar' in c]
    racmo_cols = [c for c in cols if 'racmo' in c]
    hirham_cols = [c for c in cols if 'hirham' in c]
    merra_cols = [c for c in cols if 'merra' in c]

    mar_cols.insert(0,'DOY')
    racmo_cols.insert(0,'DOY')
    hirham_cols.insert(0,'DOY')
    merra_cols.insert(0,'DOY')

    df_mar = df[mar_cols]
    df_racmo = df[racmo_cols]
    df_hirham = df[hirham_cols]
    df_merra = df[merra_cols]

    colNames = ['DOY','<1000 m','1000-1200 m', '1200-1400 m','1400-1600 m','1600-1800 m','>1800 m']

    df_mar.columns = colNames
    df_racmo.columns = colNames
    df_hirham.columns = colNames
    df_merra.columns = colNames

    df_mar.set_index('DOY', inplace=True)
    df_racmo.set_index('DOY', inplace=True)
    df_hirham.set_index('DOY', inplace=True)
    df_merra.set_index('DOY', inplace=True)

    df_mar = df_mar /(area * 1000000)*3600*1000  #KEY: change m3/s/day into mm/day, note, 24 hour day has been added previously
    df_racmo = df_racmo /(area * 1000000)*3600*1000
    df_hirham = df_hirham /(area * 1000000)*3600*1000
    df_merra = df_merra /(area * 1000000)*3600*1000

    return df_mar,df_racmo,df_hirham,df_merra

def plot_1(df_runoff,df_all_runoff,df_racmo,df_hirham,df_merra):

    #set plotting environments
    matplotlib.style.use('classic')
    matplotlib.rcParams.update({'font.size': 25})
    matplotlib.rcParams['axes.linewidth'] = 2
    matplotlib.rcParams['xtick.major.size'] = 16
    matplotlib.rcParams['xtick.major.width'] = 2
    matplotlib.rcParams['ytick.major.size'] = 16
    matplotlib.rcParams['ytick.major.width'] = 2
    matplotlib.rcParams['lines.linewidth'] = 3
    matplotlib.rcParams['lines.markersize'] = 10
    
    f, axarr = plt.subplots(3,2)

    #f, axarr = plt.subplots(2,2)
    #Google: How to use colormaps to color plots of Pandas DataFrames
    #also see colormaps_reference
    #also see Invert colormap in matplotlib
    cmap = cm.get_cmap('bwr_r') # Colour map (there are many others)


    df_all_runoff.plot(ax=axarr[0][0],legend=False,cmap=cmap)
    df_runoff.plot(ax=axarr[0][0],legend=False,linestyle="None",marker = 'o',cmap=cmap)
    #axarr[0][0].set_xlabel('DOY')
    axarr[0][0].set_ylabel('daily R (mm)')
    axarr[0][0].annotate('(a)',size = 20,xy=get_axis_limits(axarr[0][0]))
    #axarr[0][0].set_ylim([0, 60])
    axarr[0][0].set_xlim([160, 240])


    df_all_runoff = df_all_runoff.cumsum()
    df_acc_runoff = select_doy_Runoff_from_all(df_runoff,df_all_runoff)
    df_all_runoff.plot(ax=axarr[0][1],legend=False,cmap=cmap)
    df_acc_runoff.plot(ax=axarr[0][1],legend=False,linestyle="None",marker = 'o',cmap=cmap)
    #axarr[0][0].set_xlabel('DOY')
    axarr[0][1].set_ylabel('acc R (mm)')
    axarr[0][1].annotate('(a)',size = 20,xy=get_axis_limits(axarr[0][1]))
    axarr[0][1].set_ylim([0, 600])
    #axarr[0][1].set_yticks(np.arange(0,800,200))
    axarr[0][1].set_xlim([160, 240])

    df_racmo.plot(ax=axarr[1][0],legend=False,cmap=cmap)
    df_runoff = select_doy_Runoff_from_all(df_runoff,df_racmo)
    df_runoff.plot(ax=axarr[1][0],legend=False,linestyle="None",marker = 'o',cmap=cmap)
    #axarr[0][0].set_xlabel('DOY')
    axarr[1][0].set_ylabel('daily R (mm)')
    axarr[1][0].annotate('(a)',size = 20,xy=get_axis_limits(axarr[1][0]))
    axarr[1][0].set_ylim([0, 70])
    axarr[1][0].set_xlim([160, 240])

    df_racmo = df_racmo.cumsum()
    df_acc_runoff = select_doy_Runoff_from_all(df_runoff,df_racmo)
    df_racmo.plot(ax=axarr[1][1],legend=False,cmap=cmap)
    df_acc_runoff.plot(ax=axarr[1][1],legend=False,linestyle="None",marker = 'o',cmap=cmap)
    #axarr[0][0].set_xlabel('DOY')
    axarr[1][1].set_ylabel('acc R (mm)')
    axarr[1][1].annotate('(a)',size = 20,xy=get_axis_limits(axarr[1][1]))
    axarr[1][1].set_ylim([0, 600])
    #axarr[1][1].set_yticks(np.arange(0,800,200))
    axarr[1][1].set_xlim([160, 240])

    df_merra.plot(ax=axarr[2][0],legend=False,cmap=cmap)
    df_runoff = select_doy_Runoff_from_all(df_runoff,df_merra)
    df_runoff.plot(ax=axarr[2][0],legend=False,linestyle="None",marker = 'o',cmap=cmap)
    axarr[2][0].set_xlabel('DOY')
    axarr[2][0].set_ylabel('daily R (mm)')
    axarr[2][0].annotate('(a)',size = 20,xy=get_axis_limits(axarr[2][0]))
    #axarr[1][0].set_ylim([0, 60])
    axarr[2][0].set_xlim([160, 240])

    df_merra = df_merra.cumsum()
    df_acc_runoff = select_doy_Runoff_from_all(df_runoff,df_merra)
    df_merra.plot(ax=axarr[2][1],legend=False,cmap=cmap)
    df_acc_runoff.plot(ax=axarr[2][1],legend=False,linestyle="None",marker = 'o',cmap=cmap)
    axarr[2][1].set_xlabel('DOY')
    axarr[2][1].set_ylabel('acc R (mm)')
    axarr[2][1].annotate('(a)',size = 20,xy=get_axis_limits(axarr[2][1]))
    axarr[2][1].set_ylim([0, 600])
    #axarr[1][1].set_yticks(np.arange(0,800,200))
    axarr[2][1].set_xlim([160, 240])

    #axarr[2][1].legend(loc='upper left',fontsize=15)

    plt.show()

    f.savefig(r'E:\seasonal_evolution_2015.tif', format='tif', dpi=450)


# Before running this script, run E:\1.GrIS_river_evolution\00_codes\lake_filling_vs_SMB_runoff_tempuse, step 1-4 to get runoff for all SMB models
# note run SMB_Step4_calculate_smb_runoff_for_specific_days_new.py!! 2018.03.29
input_smb_file = r'E:\1.GrIS_river_evolution\00_codes\lake_filling_vs_SMB_runoff_tempuse\output_smb_runoff_output_for_DOYs.xlsx'


#output of step 13
smbPath = r'E:\1.GrIS_river_evolution\1_SMB_outputs\2015'
all_runoffFile = smbPath + '\\mar_7_5km_lat_lon_ps_basin_Watson_Isortoq_cells_runoff_output.csv'
all_meltFile = smbPath + '\\mar_7_5km_lat_lon_ps_basin_Watson_Isortoq_cells_melt_output.csv'
all_nd_runoffFile = smbPath + '\\mar_7_5km_lat_lon_ps_basin_Watson_Isortoq_cells_nondelayed_runoff_output.csv'
#output of step 14
runoffFile = smbPath + '\\DOYs_mar_7_5km_lat_lon_ps_basin_Watson_Isortoq_cells_runoff_output.xlsx'
nd_runoffFile = smbPath + '\\DOYs_mar_7_5km_lat_lon_ps_basin_Watson_Isortoq_cells_nondelayed_runoff_output.xlsx'
df_runoff = create_SMB_DF(runoffFile)
df_all_runoff = create_SMB_DF(all_runoffFile)

#output of step 7, only used to get eleBin area
zonalSta_waterarea_point_file = r'E:\1.GrIS_river_evolution\water_mask\2015\Watson_Isortoq\zonalstats\ele_pt_waterarea.dbf'
area = get_eleBin_area(zonalSta_waterarea_point_file)

#Note: runoff, all runoff are read from daily 7.5 km MAR models (Xavier), while df_mar is the 2015 hourly MAR data from Marco. They are very similar
df_mar,df_racmo,df_hirham,df_merra = create_all_SMB_DF(input_smb_file,area)


plot_1(df_runoff,df_all_runoff,df_racmo,df_hirham,df_merra)